@@ -1,12 +1,12 @@
 ;;; vertico-mouse.el --- Mouse support for Vertico -*- lexical-binding: t -*-
 
-;; Copyright (C) 2021-2024 Free Software Foundation, Inc.
+;; Copyright (C) 2021-2025 Free Software Foundation, Inc.
 
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2021
-;; Version: 1.10
-;; Package-Requires: ((emacs "28.1") (compat "30") (vertico "1.10"))
+;; Version: 1.11
+;; Package-Requires: ((emacs "28.1") (compat "30") (vertico "1.11"))
 ;; URL: https://github.com/minad/vertico
 
 ;; This file is part of GNU Emacs.
@@ -86,8 +86,6 @@
 (cl-defmethod vertico--setup :after (&context (vertico-mouse-mode (eql t)))
   (when (boundp 'mwheel-coalesce-scroll-events)
     (setq-local mwheel-coalesce-scroll-events t))
-  (when (boundp 'pixel-scroll-precision-mode)
-    (setq-local pixel-scroll-precision-mode nil))
   (setq-local mwheel-scroll-up-function #'vertico-mouse--scroll-up
               mwheel-scroll-down-function #'vertico-mouse--scroll-down))
 
